function [phi,U,V]=Continueer(X,nx,ny,Model)
%[phi,U,V]=Continueer(X,nx,ny,Model)
%  Zet de oplossingsvector X om naar een roosterfunctie phi 
% (van de grondwaterdruk/concentratie verontreiniging) gedefinieerd
%  op het grid met nx bij ny inwendige roosterpunten. Continueer phi mbv 
%  modelgegevens in Model  naar roosterpunten op de rand en bepaal
%  het bijbehorend stromingsveld (U,V)=-(a d_x phi , b d_y phi) met
%  gebruikmaken van de randvoorwaarden die in het model gefenieerd zijn.


global DISCRETIESATIEORDERAND
DISCRETIESATIEORDERAND=0;

% Genereer gebied en stapgroottes
i=1:nx; j=1:ny;
[X0,Y0]=feval(Model,'gebied');
hx=X0/(nx+1); hy=Y0/(ny+1);

% Zet de vector X om naar een roosterfunctie phi.
phi(i+1,j+1)=reshape(X,nx,ny);

% phi is gedefineerd op roosterpunten in het inwendige.
% Extrapoleer de waarde phi naar de roosterpunten op de rand.

%% Bereken de coefficienten in de roosterpunten op de rand
xi=i*hx;      yj=j*hy;
[psiwg,muwg]=feval(Model,yj,'westrand'); 
[psiog,muog]=feval(Model,yj,'oostrand'); 

%% gebruik de randvoorwaarden om de functie phi voort te zetten
%% tot de rand
%% randvoorwaarden, mu=0 voor 1-ste orde, mu=0.5 voor 2-de orde 
mu=DISCRETIESATIEORDERAND; mu1=1+mu; mu2=1+2*mu;

%% west rand
% phi(1,j+1)=2*phi(2,j+1)-phi(3,j+1); %% extrapoleer
[a,b0]=feval(Model,0.5*hx+0*yj,yj,'diffusie');
teller=muwg.*a/hx; noemer=1-muwg-mu1*teller; 
phi(1,j+1)=(psiwg-teller.*(mu2*phi(2,j+1)-mu*phi(3,j+1)))./noemer;

%% oost rand
%  phi(nx+2,j+1)=2*phi(nx+1,j+1)-phi(nx,j+1);%% extrapoleer
[a,b0]=feval(Model,(nx+0.5)*hx+0*yj,yj,'diffusie');
teller=muog.*a/hx; noemer=1-muog-mu1*teller; 
phi(nx+2,j+1)=(psiog-teller.*(mu2*phi(nx+1,j+1)-mu*phi(nx,j+1)))./noemer;

%% zuid rand 
% phi(i+1,1)=2*phi(i+1,2)-phi(i+1,3);%% extrapoleer
xi0=[0,xi,nx+1]'; i0=1:nx+2;
[psizg,muzg]=feval(Model,xi0,'zuidrand'); 
[a0,b]=feval(Model,xi0,0.5*hy+0*xi0,'diffusie');
teller=muzg.*b/hy; noemer=1-muzg-mu1*teller; 
phi(i0,1)=(psizg-teller.*(mu2*phi(i0,2)-mu*phi(i0,3)))./noemer;

%%  noord rand
% phi(i+1,ny+2)=2*phi(i+1,ny+1)-phi(i+1,ny);%% extrapoleer
[psing,mung]=feval(Model,xi0,'noordrand'); 
[a0,b]=feval(Model,xi0,(ny+0.5)*hy+0*xi0,'diffusie');
teller=mung.*b/hy; noemer=1-mung-mu1*teller; 
phi(i0,ny+2)=(psing-teller.*(mu2*phi(i0,ny+1)-mu*phi(i0,ny)))./noemer;


%% hoekpunten %% extrapoleer
% phi(1,1)=2*phi(2,2)-phi(3,3); 
% phi(nx+2,1)=2*phi(nx+1,2)-phi(nx,3); 
% phi(1,ny+2)=2*phi(2,ny+1)-phi(3,ny); 
% phi(nx+2,ny+2)=2*phi(nx+1,ny+1)-phi(nx,ny); 



% bereken het stromings veld
% bepaal eerst de doorlaadbaarheidscoefficienten op het rooster
[x,y]=ndgrid((0.5:1:nx+1)*hx,j*hy); 
[ag,bg0]=feval(Model,x,y,'diffusie');
[x,y]=ndgrid(i*hx,(0.5:1:ny+1)*hy); 
[ag0,bg]=feval(Model,x,y,'diffusie');; 

U=-ag.*(phi([2:nx+2],j+1)-phi([1:nx+1],j+1))/hx;
V=-bg.*(phi(i+1,[2:ny+2])-phi(i+1,[1:ny+1]))/hy;

return
