function Vertoon(Model,phi,U,V,Nivos,Schaal)
% Plot de oplossing phi (grondwaterdruk/concentratie verontreiniging)
% en het stromingsveld (U,V)=-(a d_x phi , b d_y phi)

global SHOWGRAPHS

figure
[nx,ny]=size(phi); nx=nx-2; ny=ny-2;

i=1:nx; j=1:ny;
[X0,Y0]=feval(Model,'gebied');
hx=X0/(nx+1); hy=Y0/(ny+1);
xi=i*hx; yj=j*hy;

% teken de contourlijnen van de druk
[xr,yr]=ndgrid([0,xi,X0],[0,yj,Y0]);
clabel(contour(xr,yr,phi,Nivos,'b-'))

% teken het vectorveld van de stroming
if nx*ny<601

  [x,y]=ndgrid([hx:hx:X0-hx],[hy:hy:Y0-hy]);
  UU=(U(i+1,j)+U(i,j))/2; VV=(V(i,j+1)+V(i,j))/2;
  
  Schaal=FindScale(UU,VV);
  
  hold on, quiver(x,y,UU,VV,Schaal,'bo','MarkerSize',2)

  II=[0*j,xi;X0+0*j,xi]; JJ=[yj,0*i;yj,Y0+0*i];
  plot(II,JJ,'m:'),axis([0,X0,0,Y0]),hold on   

else
  % als er te veel roosterpunten zijn 
  % is het te druk om het vectorveld van de stroming in 
  % alle roosterpunten te tekenen:
  % werk met een deelrooster
  Nx=20;            Ny=20;
  Phx=X0/(Nx+1);    Phy=Y0/(Ny+1);
  Pxi=[1:Nx]*Phx;   Pyj=[1:Ny]*Phy;

  ii=round(Pxi/hx); jj=floor(Pyj/hy);
  r=Pxi/hx-ii;      s=Pyj/hy-jj;
  UU=diag(r)*(U(ii+1,:)-U(ii,:))+U(ii,:);
  UU=(UU(:,jj+1)-UU(:,jj))*diag(s)+UU(:,jj);

  ii=floor(Pxi/hx); jj=round(Pyj/hy);
  r=Pxi/hx-ii;      s=Pyj/hy-jj;
  VV=diag(r)*(V(ii+1,:)-V(ii,:))+V(ii,:);
  VV=(VV(:,jj+1)-VV(:,jj))*diag(s)+VV(:,jj);

  Schaal=FindScale(UU,VV);

  hold on, quiver(Pxi,Pyj,UU',VV',Schaal,'bo','MarkerSize',2)

end


pomp=feval(Model,'pomp');
if ~isempty(pomp)
  [k,l]=size(pomp);
  kk=1:k; 
  ii=round(pomp(kk,1)/hx); 
  jj=round(pomp(kk,2)/hy);
  plot(pomp(kk,1),pomp(kk,2),'r.','MarkerSize',20)  
  plot(ii*hx,jj*hy,'g.','MarkerSize',16)
end


rivier=feval(Model,'rivier');
if ~isempty(rivier)
  SHOWGRAPHS=0;
  [k1,l1]=size(rivier);
  for kk=1:k1
    [Snijpunt,IndexRoosterpunt,kub]=Rivier(rivier(kk,:),nx,ny,X0,Y0);
    l=size(Snijpunt,2);
    plot(Snijpunt(1,[1,l]),Snijpunt(2,[1,l]),'b-','LineWidth',3)
    if nx*ny<601
      Roosterpunt=diag([hx,hy])*IndexRoosterpunt;
      plot(Roosterpunt(1,:),Roosterpunt(2,:),'g.')
    end
  end
end

hold off
figure, meshc(xr,yr,phi), view(-10,30)

return

%===================================
function S=FindScale(U,V)
% find a scaling of the velocity field
%

   [nx,ny]=size(U); n=nx*ny;
   Lu=reshape(U,n,1); Lv=reshape(V,n,1);
   L=sqrt(Lu.*Lu+Lv.*Lv);
   [L,J]=sort(L,'descend');
   k=min(30,length(L));
   S=L(1)/L(k);

return

